# NSB tuned Config

## zen40az180_dl1ab_tuned_nsb_src1

## Short description of the config

Config for 40zd and 180deg with tuning to the NSB of the required field

## Why this config is needed

Processing of data with specific NSB 